@@ -2,7 +2,7 @@ from asyncio import Task
 
 from sqlalchemy import Column, Integer, String, Float, Boolean
 
-from .session import Base, init_tables
+from .session import Base
 from ..config import cfg
 from ..enums import CommandContext
 
@@ -88,6 +88,3 @@ class MessageTimer(Base):
     @classmethod
     def create(cls, channel: str, name: str, message: str, interval: float, active=False):
         return MessageTimer(name=name, channel=channel, message=message, interval=interval, active=active)
-
-
-init_tables()
