@@ -1,8 +1,10 @@
+import json
 from typing import Any
 
 __all__ = [
     'dict_get_value',
     'dict_has_keys',
+    'try_parse_json',
 ]
 
 
@@ -27,3 +29,13 @@ def dict_get_value(data: dict, *keys, default: Any = None) -> Any:
             return default
 
     return data
+
+
+def try_parse_json(data, **default_keys) -> dict:
+    if isinstance(data, dict):
+        return data
+
+    try:
+        return json.loads(data)
+    except (TypeError, json.JSONDecodeError) as _:
+        return default_keys
